@@ -4,10 +4,15 @@
 #' @export
 BF.coeftest <- function(x,
                      hypothesis = NULL,
+                     prior.hyp.explo = NULL,
+                     prior.hyp.conf = NULL,
                      prior.hyp = NULL,
                      complement = TRUE,
+                     log = FALSE,
                      ...){
 
+  logIN <- log
+
   Sigma <- diag(x[, 2L]^2)
   n <- attr(x, "nobs")
 
@@ -16,7 +21,7 @@ BF.coeftest <- function(x,
   if(!is.null(prior.hyp)) warning("prior specification via 'prior.hyp' is not supported for objects of class 'coeftest'")
   #if(!exploratory) stop("only exploratory hypothesis testing is supported for objects of class 'coeftest'")
 
-  out <- BF.default(x[, 1L], Sigma = Sigma, n = n, ...)
+  out <- BF.default(x[, 1L], Sigma = Sigma, n = n, log = logIN, ...)
   out$model <- x
   out$call <- match.call()
   out
