@@ -7,8 +7,11 @@
 #' @export
 BF.default <- function(x,
                        hypothesis = NULL,
+                       prior.hyp.explo = NULL,
+                       prior.hyp.conf = NULL,
                        prior.hyp = NULL,
                        complement = TRUE,
+                       log = FALSE,
                        Sigma,
                        n,
                        ...){
@@ -19,12 +22,15 @@ BF.default <- function(x,
 
   # use Savage-Dickey approximation of the BF
   BF_out <- Savage.Dickey.Gaussian(prior.mean = rep(0, length(x)),
-                                         prior.sigma = Sigma * n,
-                                         post.mean = x,
-                                         post.sigma = Sigma,
-                                         hypothesis = hypothesis,
-                                         prior.hyp = prior.hyp,
-                                         complement = complement)
+                                        prior.sigma = Sigma * n,
+                                        post.mean = x,
+                                        post.sigma = Sigma,
+                                        hypothesis = hypothesis,
+                                        prior.hyp.explo = prior.hyp.explo,
+                                        prior.hyp.conf = prior.hyp.conf,
+                                        prior.hyp = prior.hyp,
+                                        complement = complement,
+                                        log = log)
 
   BF_out$model <- x
   BF_out$call <- match.call()
@@ -41,8 +47,11 @@ Savage.Dickey.Gaussian <- function(prior.mean,
                                    post.mean,
                                    post.sigma,
                                    hypothesis,
+                                   prior.hyp.explo,
+                                   prior.hyp.conf,
                                    prior.hyp,
-                                   complement){
+                                   complement,
+                                   log = FALSE){
 
   #prior.mean is a normal prior mean of key parameters
   #prior.sigma is a normal prior covariance matrix of key parameters
@@ -58,18 +67,33 @@ Savage.Dickey.Gaussian <- function(prior.mean,
   covm0 <- prior.sigma
   mean0 <- prior.mean # for constrained testing prior mean is relocated to 'boundary of constrained space'
 
-  # compute exploratory BFs for each parameter
-  relfit <- matrix(c(dnorm(0,mean=meanN,sd=sqrt(diag(covmN))),
-                     pnorm(0,mean=meanN,sd=sqrt(diag(covmN))),
-                     1-pnorm(0,mean=meanN,sd=sqrt(diag(covmN)))),ncol=3)
+  logIN <- log
 
-  relcomp <- matrix(c(dnorm(0,mean=mean0,sd=sqrt(diag(covm0))),
-                      pnorm(0,mean=mean0,sd=sqrt(diag(covm0))),
-                      1-pnorm(0,mean=mean0,sd=sqrt(diag(covm0)))),ncol=3)
-  BFtu_exploratory <- relfit / relcomp
-  PHP_exploratory <- round(BFtu_exploratory / apply(BFtu_exploratory,1,sum),3)
+  # check proper usage of argument 'prior.hyp.conf' and 'prior.hyp.explo'
+  if(!is.null(prior.hyp.conf)){
+    prior.hyp <- prior.hyp.conf
+  }
+  dummy <- 123
+  class(dummy) <- "dummy"
+  prior.hyp.explo <- process.prior.hyp.explo(prior_hyp_explo = prior.hyp.explo, model=dummy)
+
+  # compute exploratory BFs for each parameter
+  relfit <- matrix(c(dnorm(0,mean=meanN,sd=sqrt(diag(covmN)),log=TRUE),
+                     pnorm(0,mean=meanN,sd=sqrt(diag(covmN)),log.p=TRUE),
+                     pnorm(0,mean=meanN,sd=sqrt(diag(covmN)),log.p=TRUE,lower.tail = FALSE)),ncol=3)
+
+  relcomp <- matrix(c(dnorm(0,mean=mean0,sd=sqrt(diag(covm0)),log=TRUE),
+                      pnorm(0,mean=mean0,sd=sqrt(diag(covm0)),log.p=TRUE),
+                      pnorm(0,mean=mean0,sd=sqrt(diag(covm0)),log.p=TRUE,lower.tail = FALSE)),ncol=3)
+  BFtu_exploratory <- relfit - relcomp
+  maxrow <- apply(BFtu_exploratory,1,max)
+  norm_BF_explo <- exp(BFtu_exploratory - maxrow %*% t(rep(1,3))) * (rep(1,nrow(relcomp)) %*% t(prior.hyp.explo[[1]]))
+  PHP_exploratory <- norm_BF_explo / apply(norm_BF_explo,1,sum)
+  # PHP_exploratory <- round(exp(BFtu_exploratory - maxrow %*% t(rep(1,3))) /
+  #                            apply(exp(BFtu_exploratory - maxrow %*% t(rep(1,3))),1,sum),3)
   colnames(PHP_exploratory) <- c("Pr(=0)","Pr(<0)","Pr(>0)")
-  row.names(PHP_exploratory) <- names_coef
+  row.names(PHP_exploratory) <- row.names(BFtu_exploratory) <- names_coef
+  colnames(BFtu_exploratory) <- c("H(=0)","H(<0)","H(>0)")
 
   # compute posterior estimates
   postestimates <- cbind(meanN,meanN,
@@ -82,6 +106,10 @@ Savage.Dickey.Gaussian <- function(prior.mean,
   row.names(postestimates) <- names_coef
   colnames(postestimates) <- c("mean","median","2.5%","97.5%")
 
+  if(logIN == FALSE){
+    BFtu_exploratory <- exp(BFtu_exploratory)
+  }
+
   if(is.null(hypothesis)){
     BFtu_confirmatory <- PHP_confirmatory <- BFmatrix_confirmatory <- relfit <-
       relcomp <- BFtable <- hypotheses <- priorprobs <- NULL
@@ -157,7 +185,7 @@ Savage.Dickey.Gaussian <- function(prior.mean,
     colnames(relfit) <- c("f_E", "f_0")
 
     # the BF for the complement hypothesis vs Hu needs to be computed.
-    BFtu_confirmatory <- c(apply(relfit / relcomp, 1, prod))
+    BFtu_confirmatory <- c(apply(relfit - relcomp, 1, sum))
     # Check input of prior probabilies
     if(is.null(prior.hyp)){
       priorprobs <- rep(1/length(BFtu_confirmatory),length(BFtu_confirmatory))
@@ -171,14 +199,17 @@ Savage.Dickey.Gaussian <- function(prior.mean,
     }
     names(priorprobs) <- hypothesisshort
 
-    PHP_confirmatory <- round(BFtu_confirmatory*priorprobs / sum(BFtu_confirmatory*priorprobs),3)
-    BFtable <- cbind(relcomp,relfit,relfit[,1]/relcomp[,1],relfit[,2]/relcomp[,2],
-                     apply(relfit,1,prod)/apply(relcomp,1,prod),PHP_confirmatory)
+    maxBFtu <- max(BFtu_confirmatory)
+    PHP_confirmatory <- round(exp(BFtu_confirmatory-maxBFtu)*priorprobs /
+                                sum(exp(BFtu_confirmatory-maxBFtu)*priorprobs),3)
+    BFtable <- cbind(relcomp,relfit,relfit[,1]-relcomp[,1],relfit[,2]-relcomp[,2],
+                     exp(apply(relfit,1,sum)-apply(relcomp,1,sum)),PHP_confirmatory)
+    BFtable[,1:7] <- exp(BFtable[,1:7])
     row.names(BFtable) <- names(PHP_confirmatory)
     colnames(BFtable) <- c("complex=","complex>","fit=","fit>","BF=","BF>","BF","PHP")
-    BFmatrix_confirmatory <- matrix(rep(BFtu_confirmatory,length(BFtu_confirmatory)),ncol=length(BFtu_confirmatory))/
+    BFmatrix_confirmatory <- matrix(rep(BFtu_confirmatory,length(BFtu_confirmatory)),ncol=length(BFtu_confirmatory)) -
       t(matrix(rep(BFtu_confirmatory,length(BFtu_confirmatory)),ncol=length(BFtu_confirmatory)))
-    diag(BFmatrix_confirmatory) <- 1
+    diag(BFmatrix_confirmatory) <- log(1)
     # row.names(BFmatrix_confirmatory) <- Hnames
     # colnames(BFmatrix_confirmatory) <- Hnames
     if(nrow(relfit)==length(parse_hyp$original_hypothesis)){
@@ -186,6 +217,11 @@ Savage.Dickey.Gaussian <- function(prior.mean,
     }else{
       hypotheses <- c(parse_hyp$original_hypothesis,"complement")
     }
+
+    if(logIN == FALSE){
+      BFtu_confirmatory <- exp(BFtu_confirmatory)
+      BFmatrix_confirmatory <- exp(BFmatrix_confirmatory)
+    }
   }
 
   BF_out <- list(
@@ -195,12 +231,14 @@ Savage.Dickey.Gaussian <- function(prior.mean,
     PHP_confirmatory=PHP_confirmatory,
     BFmatrix_confirmatory=BFmatrix_confirmatory,
     BFtable_confirmatory=BFtable,
-    prior.hyp=priorprobs,
+    prior.hyp.explo=prior.hyp.explo,
+    prior.hyp.conf=priorprobs,
     hypotheses=hypotheses,
     estimates=postestimates,
     model=NULL,
     bayesfactor="Bayes factors using Gaussian approximations",
     parameter="general parameters",
+    log = logIN,
     call=NULL)
 
   class(BF_out) <- "BF"
@@ -213,7 +251,7 @@ Savage.Dickey.Gaussian <- function(prior.mean,
 #' @importFrom mvtnorm dmvnorm pmvnorm
 Gaussian_measures <- function(mean1,Sigma1,n1=0,RrE1,RrO1,names1=NULL,constraints1=NULL){
   K <- length(mean1)
-  relE <- relO <- 1
+  relE <- relO <- log(1)
   if(!is.null(RrE1) && is.null(RrO1)){ #only equality constraints
     RE1 <- RrE1[,-(K+1)]
     if(!is.matrix(RE1)){
@@ -223,7 +261,7 @@ Gaussian_measures <- function(mean1,Sigma1,n1=0,RrE1,RrO1,names1=NULL,constraint
     qE1 <- nrow(RE1)
     meanE <- RE1%*%mean1
     SigmaE <- RE1%*%Sigma1%*%t(RE1)
-    relE <- dmvnorm(rE1,mean=c(meanE),sigma=SigmaE,log=FALSE)
+    relE <- dmvnorm(rE1,mean=c(meanE),sigma=SigmaE,log=TRUE)
   }
   if(is.null(RrE1) && !is.null(RrO1)){ #only order constraints
     RO1 <- RrO1[,-(K+1)]
@@ -237,19 +275,19 @@ Gaussian_measures <- function(mean1,Sigma1,n1=0,RrE1,RrO1,names1=NULL,constraint
       meanO <- c(RO1%*%mean1)
       SigmaO <- RO1%*%Sigma1%*%t(RO1)
       check_vcov(SigmaO)
-      relO <- pmvnorm(lower=rO1,upper=Inf,mean=meanO,sigma=SigmaO)[1]
+      relO <- log(pmvnorm(lower=rO1,upper=Inf,mean=meanO,sigma=SigmaO)[1])
     }else{ #no linear transformation can be used; pmvt cannot be used. Use bain with a multivariate normal approximation
       names(mean1) <- names1
       if(n1>0){ # we need prior measures
         mean1vec <- c(mean1)
         names(mean1vec) <- names1
         bain_res <- bain(x=mean1vec,hypothesis=constraints1,Sigma=Sigma1,n=n1)
-        relO <- bain_res$fit[1,4]
+        relO <- log(bain_res$fit[1,4])
       }else { # we need posterior measures (there is very little information)
         mean1vec <- c(mean1)
         names(mean1vec) <- names1
         bain_res <- bain(x=mean1vec,hypothesis=constraints1,Sigma=Sigma1,n=999) #n not used in computation
-        relO <- bain_res$fit[1,3]
+        relO <- log(bain_res$fit[1,3])
       }
     }
   }
@@ -278,7 +316,7 @@ Gaussian_measures <- function(mean1,Sigma1,n1=0,RrE1,RrO1,names1=NULL,constraint
       TSigma1 <- R1 %*% Sigma1 %*% t(R1)
 
       # relative meausure for equalities
-      relE <- dmvnorm(x=rE1,mean=Tmean1[1:qE1],sigma=matrix(TSigma1[1:qE1,1:qE1],ncol=qE1),log=FALSE)
+      relE <- dmvnorm(x=rE1,mean=Tmean1[1:qE1],sigma=matrix(TSigma1[1:qE1,1:qE1],ncol=qE1),log=TRUE)
 
       # Partitioning equality part and order part
       Tmean1E <- Tmean1[1:qE1]
@@ -292,18 +330,18 @@ Gaussian_measures <- function(mean1,Sigma1,n1=0,RrE1,RrO1,names1=NULL,constraint
       Tmean1OgE <- Tmean1O + TSigma1OE %*% solve(TSigma1EE) %*% (rE1-Tmean1E)
       TSigma1OgE <- TSigma1OO - TSigma1OE %*% solve(TSigma1EE) %*% t(TSigma1OE)
 
-      relO <- pmvnorm(lower=rO1,upper=Inf,mean=c(Tmean1OgE),sigma=TSigma1OgE)[1]
+      relO <- log(pmvnorm(lower=rO1,upper=Inf,mean=c(Tmean1OgE),sigma=TSigma1OgE)[1])
 
     }else{ #use bain for the computation of the probability
       names(mean1) <- names1
       if(n1>0){ # we need prior measures
         bain_res <- bain(x=c(mean1),hypothesis=constraints1,Sigma=Sigma1,n=n1)
-        relO <- bain_res$fit[1,4]
-        relE <- bain_res$fit[1,2]
+        relO <- log(bain_res$fit[1,4])
+        relE <- log(bain_res$fit[1,2])
       }else { # we need posterior measures (there is very little information)
         bain_res <- bain(x=c(mean1),hypothesis=constraints1,Sigma=Sigma1,n=999) #n not used in computation
-        relO <- bain_res$fit[1,3]
-        relE <- bain_res$fit[1,1]
+        relO <- log(bain_res$fit[1,3])
+        relE <- log(bain_res$fit[1,1])
       }
     }
   }
@@ -317,15 +355,15 @@ Gaussian_prob_Hc <- function(mean1,Sigma1,relmeas,RrO){
 
   numpara <- length(mean1)
   numhyp <- nrow(relmeas)
-  which_eq <- relmeas[,1] != 1
+  which_eq <- relmeas[,1] != log(1)
   if(sum(which_eq)==numhyp){ # Then the complement is equivalent to the unconstrained hypothesis.
-    relmeas <- rbind(relmeas,rep(1,2))
+    relmeas <- rbind(relmeas,rep(log(1),2))
     rownames(relmeas)[numhyp+1] <- "complement"
   }else{ # So there is at least one hypothesis with only order constraints
     welk <- which(!which_eq)
     if(length(welk)==1){ # There is one hypothesis with only order constraints. Hc is complement of this hypothesis.
-      relmeas <- rbind(relmeas,rep(1,2))
-      relmeas[numhyp+1,2] <- 1 - relmeas[welk,2]
+      relmeas <- rbind(relmeas,rep(log(1),2))
+      relmeas[numhyp+1,2] <- log(1 - exp(relmeas[welk,2]))
       rownames(relmeas)[numhyp+1] <- "complement"
     }else{ # So more than one hypothesis with only order constraints
       # First we check whether ther is an overlap between the order constrained spaces.
@@ -344,8 +382,8 @@ Gaussian_prob_Hc <- function(mean1,Sigma1,relmeas,RrO){
 
       if(sum(checkOCplus > 0) < draws2){ #then the joint order constrained hypotheses do not completely cover the parameter space.
         if(sum(checkOCplus>1)==0){ # then order constrained spaces are nonoverlapping
-          relmeas <- rbind(relmeas,rep(1,2))
-          relmeas[numhyp+1,2] <- 1 - sum(relmeas[welk,2])
+          relmeas <- rbind(relmeas,rep(log(1),2))
+          relmeas[numhyp+1,2] <- log(1 - sum(exp(relmeas[welk,2])))
           rownames(relmeas)[numhyp+1] <- "complement"
         }else{ #the order constrained subspaces at least partly overlap
 
@@ -361,8 +399,8 @@ Gaussian_prob_Hc <- function(mean1,Sigma1,relmeas,RrO){
             rorder <- as.matrix(RrO[[h]][,1+numpara])
             apply(randomDraws%*%t(Rorder) > rep(1,draws2)%*%t(rorder),1,prod)
           })
-          relmeas <- rbind(relmeas,rep(1,2))
-          relmeas[numhyp+1,2] <- sum(Reduce("+",checksOCpost) == 0) / draws2
+          relmeas <- rbind(relmeas,rep(log(1),2))
+          relmeas[numhyp+1,2] <- log(sum(Reduce("+",checksOCpost) == 0) / draws2)
           rownames(relmeas)[numhyp+1] <- "complement"
         }
       }
