@@ -13,12 +13,20 @@ test_that("exploratory metafor test for I^2", {
   skip_on_cran()
   ### Fit a random-effects model to the data
   res <- rma(yi = yi, vi = vi)
+  set.seed(123)
   BFmeta1 <- BF(res)
+  set.seed(123)
+  BFmeta1a <- BF(res,prior.hyp.explo = c(5:7))
   expect_equivalent(
-    round(BFmeta1$PHP_exploratory[1,],3),c(0.086,0.013,0.902), tolerance = .05
+    round(BFmeta1$PHP_exploratory[1,],3),c(0.086,0.009,0.905), tolerance = .05
   )
   expect_equivalent(
-    round(BFmeta1$PHP_exploratory[2,],3),c(.800,0.086,0.114), tolerance = .05
+    round(BFmeta1$PHP_exploratory[2,],3),c(.799,0.085,0.116), tolerance = .05
+  )
+  expect_equivalent(
+    unname(round(BFmeta1a$PHP_exploratory[2,],3)),
+    unname(round(BFmeta1$BFtu_exploratory[2,]*(5:7)/sum(BFmeta1$BFtu_exploratory[2,]*(5:7)),3)),
+    tolerance = .05
   )
 })
 
