@@ -9,5 +9,5 @@ BF1 <- BF(res)
 #check results exploratory test
 test_that("metafor exploratory test", {
   expect_equivalent(
-    round(BF1$BFtu_exploratory[1,],3),c(0.236,0.038,1.349), tolerance = .05
+    round(BF1$BFtu_exploratory[,3],3),c(1.35,2), tolerance = .05
   )})
